# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/mocap/Vicon.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.math.Vec3DDouble_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/mocap/Vicon.proto',
  package='rst.devices.mocap',
  serialized_pb='\n\x1drst/devices/mocap/Vicon.proto\x12\x11rst.devices.mocap\x1a\x1arst/math/Vec3DDouble.proto\"\xa5\x06\n\x05Vicon\x12\r\n\x05\x66rame\x18\x01 \x02(\x04\x12\x33\n\x08timecode\x18\x02 \x01(\x0b\x32!.rst.devices.mocap.Vicon.Timecode\x12\x31\n\x07subject\x18\x03 \x03(\x0b\x32 .rst.devices.mocap.Vicon.Subject\x12\x42\n\x10unlabeled_marker\x18\x04 \x03(\x0b\x32(.rst.devices.mocap.Vicon.UnlabeledMarker\x1aK\n\x0fUnlabeledMarker\x12\x0c\n\x04name\x18\x01 \x02(\t\x12*\n\x0btranslation\x18\x02 \x02(\x0b\x32\x15.rst.math.Vec3DDouble\x1a\x64\n\x08Timecode\x12\r\n\x05hours\x18\x01 \x02(\r\x12\x0f\n\x07minutes\x18\x02 \x02(\r\x12\x0f\n\x07seconds\x18\x03 \x02(\r\x12\x11\n\x06\x66rames\x18\x04 \x01(\r:\x01\x30\x12\x14\n\tsub_frame\x18\x05 \x01(\r:\x01\x30\x1a\xe0\x02\n\x07Segment\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x38\n\x07markers\x18\x02 \x03(\x0b\x32\'.rst.devices.mocap.Vicon.Segment.Marker\x12*\n\x0btranslation\x18\x03 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x12\x30\n\x11\x65uler_orientation\x18\x04 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x12\x32\n\x13helical_orientation\x18\x05 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x12\x37\n\x18quaternionen_orientation\x18\x06 \x01(\x0b\x32\x15.rst.math.Vec3DDouble\x1a\x42\n\x06Marker\x12\x0c\n\x04name\x18\x01 \x02(\t\x12*\n\x0btranslation\x18\x02 \x02(\x0b\x32\x15.rst.math.Vec3DDouble\x1aK\n\x07Subject\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x32\n\x08segments\x18\x02 \x03(\x0b\x32 .rst.devices.mocap.Vicon.SegmentB\x0b\x42\tViconType')




_VICON_UNLABELEDMARKER = _descriptor.Descriptor(
  name='UnlabeledMarker',
  full_name='rst.devices.mocap.Vicon.UnlabeledMarker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.UnlabeledMarker.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.devices.mocap.Vicon.UnlabeledMarker.translation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=277,
  serialized_end=352,
)

_VICON_TIMECODE = _descriptor.Descriptor(
  name='Timecode',
  full_name='rst.devices.mocap.Vicon.Timecode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hours', full_name='rst.devices.mocap.Vicon.Timecode.hours', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='minutes', full_name='rst.devices.mocap.Vicon.Timecode.minutes', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seconds', full_name='rst.devices.mocap.Vicon.Timecode.seconds', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frames', full_name='rst.devices.mocap.Vicon.Timecode.frames', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sub_frame', full_name='rst.devices.mocap.Vicon.Timecode.sub_frame', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=354,
  serialized_end=454,
)

_VICON_SEGMENT_MARKER = _descriptor.Descriptor(
  name='Marker',
  full_name='rst.devices.mocap.Vicon.Segment.Marker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.Segment.Marker.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.devices.mocap.Vicon.Segment.Marker.translation', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=743,
  serialized_end=809,
)

_VICON_SEGMENT = _descriptor.Descriptor(
  name='Segment',
  full_name='rst.devices.mocap.Vicon.Segment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.Segment.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='markers', full_name='rst.devices.mocap.Vicon.Segment.markers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='translation', full_name='rst.devices.mocap.Vicon.Segment.translation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='euler_orientation', full_name='rst.devices.mocap.Vicon.Segment.euler_orientation', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='helical_orientation', full_name='rst.devices.mocap.Vicon.Segment.helical_orientation', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quaternionen_orientation', full_name='rst.devices.mocap.Vicon.Segment.quaternionen_orientation', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_VICON_SEGMENT_MARKER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=457,
  serialized_end=809,
)

_VICON_SUBJECT = _descriptor.Descriptor(
  name='Subject',
  full_name='rst.devices.mocap.Vicon.Subject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.mocap.Vicon.Subject.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='segments', full_name='rst.devices.mocap.Vicon.Subject.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=811,
  serialized_end=886,
)

_VICON = _descriptor.Descriptor(
  name='Vicon',
  full_name='rst.devices.mocap.Vicon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frame', full_name='rst.devices.mocap.Vicon.frame', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timecode', full_name='rst.devices.mocap.Vicon.timecode', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='subject', full_name='rst.devices.mocap.Vicon.subject', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unlabeled_marker', full_name='rst.devices.mocap.Vicon.unlabeled_marker', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_VICON_UNLABELEDMARKER, _VICON_TIMECODE, _VICON_SEGMENT, _VICON_SUBJECT, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=81,
  serialized_end=886,
)

_VICON_UNLABELEDMARKER.fields_by_name['translation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_UNLABELEDMARKER.containing_type = _VICON;
_VICON_TIMECODE.containing_type = _VICON;
_VICON_SEGMENT_MARKER.fields_by_name['translation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT_MARKER.containing_type = _VICON_SEGMENT;
_VICON_SEGMENT.fields_by_name['markers'].message_type = _VICON_SEGMENT_MARKER
_VICON_SEGMENT.fields_by_name['translation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.fields_by_name['euler_orientation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.fields_by_name['helical_orientation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.fields_by_name['quaternionen_orientation'].message_type = rst.math.Vec3DDouble_pb2._VEC3DDOUBLE
_VICON_SEGMENT.containing_type = _VICON;
_VICON_SUBJECT.fields_by_name['segments'].message_type = _VICON_SEGMENT
_VICON_SUBJECT.containing_type = _VICON;
_VICON.fields_by_name['timecode'].message_type = _VICON_TIMECODE
_VICON.fields_by_name['subject'].message_type = _VICON_SUBJECT
_VICON.fields_by_name['unlabeled_marker'].message_type = _VICON_UNLABELEDMARKER
DESCRIPTOR.message_types_by_name['Vicon'] = _VICON

class Vicon(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class UnlabeledMarker(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _VICON_UNLABELEDMARKER

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.UnlabeledMarker)

  class Timecode(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _VICON_TIMECODE

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Timecode)

  class Segment(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType

    class Marker(_message.Message):
      __metaclass__ = _reflection.GeneratedProtocolMessageType
      DESCRIPTOR = _VICON_SEGMENT_MARKER

      # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Segment.Marker)
    DESCRIPTOR = _VICON_SEGMENT

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Segment)

  class Subject(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _VICON_SUBJECT

    # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon.Subject)
  DESCRIPTOR = _VICON

  # @@protoc_insertion_point(class_scope:rst.devices.mocap.Vicon)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\tViconType')
# @@protoc_insertion_point(module_scope)
