# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/nao/NaoTemperatures.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/nao/NaoTemperatures.proto',
  package='rst.devices.nao',
  serialized_pb='\n%rst/devices/nao/NaoTemperatures.proto\x12\x0frst.devices.nao\"a\n\x0fNaoTemperatures\x12\r\n\x05\x62oard\x18\x01 \x01(\x02\x12\x0c\n\x04head\x18\x02 \x01(\x02\x12\x31\n\x06joints\x18\x03 \x03(\x0b\x32!.rst.devices.nao.JointTemperature\"5\n\x10JointTemperature\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x13\n\x0btemperature\x18\x02 \x02(\x02\x42\x15\x42\x13NaoTemperaturesType')




_NAOTEMPERATURES = _descriptor.Descriptor(
  name='NaoTemperatures',
  full_name='rst.devices.nao.NaoTemperatures',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='board', full_name='rst.devices.nao.NaoTemperatures.board', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='head', full_name='rst.devices.nao.NaoTemperatures.head', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='joints', full_name='rst.devices.nao.NaoTemperatures.joints', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=58,
  serialized_end=155,
)


_JOINTTEMPERATURE = _descriptor.Descriptor(
  name='JointTemperature',
  full_name='rst.devices.nao.JointTemperature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.nao.JointTemperature.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='rst.devices.nao.JointTemperature.temperature', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=157,
  serialized_end=210,
)

_NAOTEMPERATURES.fields_by_name['joints'].message_type = _JOINTTEMPERATURE
DESCRIPTOR.message_types_by_name['NaoTemperatures'] = _NAOTEMPERATURES
DESCRIPTOR.message_types_by_name['JointTemperature'] = _JOINTTEMPERATURE

class NaoTemperatures(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _NAOTEMPERATURES

  # @@protoc_insertion_point(class_scope:rst.devices.nao.NaoTemperatures)

class JointTemperature(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTTEMPERATURE

  # @@protoc_insertion_point(class_scope:rst.devices.nao.JointTemperature)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023NaoTemperaturesType')
# @@protoc_insertion_point(module_scope)
