# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/audition/FloatSoundArray.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/audition/FloatSoundArray.proto',
  package='rst.audition',
  serialized_pb='\n\"rst/audition/FloatSoundArray.proto\x12\x0crst.audition\"&\n\x0f\x46loatSoundArray\x12\x13\n\x0b\x66loatbuffer\x18\x01 \x03(\x02\x42\x15\x42\x13\x46loatSoundArrayType')




_FLOATSOUNDARRAY = _descriptor.Descriptor(
  name='FloatSoundArray',
  full_name='rst.audition.FloatSoundArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='floatbuffer', full_name='rst.audition.FloatSoundArray.floatbuffer', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=52,
  serialized_end=90,
)

DESCRIPTOR.message_types_by_name['FloatSoundArray'] = _FLOATSOUNDARRAY

class FloatSoundArray(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _FLOATSOUNDARRAY

  # @@protoc_insertion_point(class_scope:rst.audition.FloatSoundArray)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023FloatSoundArrayType')
# @@protoc_insertion_point(module_scope)
