# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/deprecated/DoNotUseMe.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/deprecated/DoNotUseMe.proto',
  package='rst.deprecated',
  serialized_pb='\n\x1frst/deprecated/DoNotUseMe.proto\x12\x0erst.deprecated\"\x0c\n\nDoNotUseMeB\x10\x42\x0e\x44oNotUseMeType')




_DONOTUSEME = _descriptor.Descriptor(
  name='DoNotUseMe',
  full_name='rst.deprecated.DoNotUseMe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=51,
  serialized_end=63,
)

DESCRIPTOR.message_types_by_name['DoNotUseMe'] = _DONOTUSEME

class DoNotUseMe(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DONOTUSEME

  # @@protoc_insertion_point(class_scope:rst.deprecated.DoNotUseMe)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016DoNotUseMeType')
# @@protoc_insertion_point(module_scope)
