# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/nao/Modules.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/nao/Modules.proto',
  package='rst.devices.nao',
  serialized_pb='\n\x1drst/devices/nao/Modules.proto\x12\x0frst.devices.nao\"j\n\x07Modules\x12(\n\x07modules\x18\x01 \x03(\x0b\x32\x17.rst.devices.nao.Module\x12\x35\n\x14\x66ramemanager_modules\x18\x02 \x03(\x0b\x32\x17.rst.devices.nao.Module\"\x16\n\x06Module\x12\x0c\n\x04name\x18\x01 \x02(\tB\rB\x0bModulesType')




_MODULES = _descriptor.Descriptor(
  name='Modules',
  full_name='rst.devices.nao.Modules',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='modules', full_name='rst.devices.nao.Modules.modules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='framemanager_modules', full_name='rst.devices.nao.Modules.framemanager_modules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=50,
  serialized_end=156,
)


_MODULE = _descriptor.Descriptor(
  name='Module',
  full_name='rst.devices.nao.Module',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.devices.nao.Module.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=158,
  serialized_end=180,
)

_MODULES.fields_by_name['modules'].message_type = _MODULE
_MODULES.fields_by_name['framemanager_modules'].message_type = _MODULE
DESCRIPTOR.message_types_by_name['Modules'] = _MODULES
DESCRIPTOR.message_types_by_name['Module'] = _MODULE

class Modules(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MODULES

  # @@protoc_insertion_point(class_scope:rst.devices.nao.Modules)

class Module(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MODULE

  # @@protoc_insertion_point(class_scope:rst.devices.nao.Module)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\013ModulesType')
# @@protoc_insertion_point(module_scope)
