# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/nao/System.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/nao/System.proto',
  package='rst.devices.nao',
  serialized_pb='\n\x1crst/devices/nao/System.proto\x12\x0frst.devices.nao\"3\n\x06System\x12\x12\n\nrobot_name\x18\x01 \x02(\t\x12\x15\n\rnaoqi_version\x18\x02 \x01(\tB\x0c\x42\nSystemType')




_SYSTEM = _descriptor.Descriptor(
  name='System',
  full_name='rst.devices.nao.System',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='robot_name', full_name='rst.devices.nao.System.robot_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='naoqi_version', full_name='rst.devices.nao.System.naoqi_version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=49,
  serialized_end=100,
)

DESCRIPTOR.message_types_by_name['System'] = _SYSTEM

class System(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SYSTEM

  # @@protoc_insertion_point(class_scope:rst.devices.nao.System)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\nSystemType')
# @@protoc_insertion_point(module_scope)
