# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/GroupHypothesis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.math.MatrixDouble_pb2
import rst.tracking.TrackingInfo_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/GroupHypothesis.proto',
  package='rst.hri',
  serialized_pb='\n\x1drst/hri/GroupHypothesis.proto\x12\x07rst.hri\x1a\x1brst/math/MatrixDouble.proto\x1a\x1frst/tracking/TrackingInfo.proto\"\xcd\x04\n\x0fGroupHypothesis\x12\x31\n\rtracking_info\x18\x01 \x01(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12\x1b\n\x13group_size_estimate\x18\n \x01(\r\x12\x42\n\x13group_size_category\x18\x0b \x01(\x0e\x32%.rst.hri.GroupHypothesis.SizeCategory\x12\x16\n\x0einterest_level\x18\x14 \x01(\x02\x12\x17\n\x0fgroup_stability\x18\x15 \x01(\x02\x12:\n\x0c\x61ge_category\x18\x1e \x01(\x0e\x32$.rst.hri.GroupHypothesis.AgeCategory\x12@\n\x0fgender_category\x18\x1f \x01(\x0e\x32\'.rst.hri.GroupHypothesis.GenderCategory\x12.\n\x0estability_cues\x18( \x01(\x0b\x32\x16.rst.math.MatrixDouble\"?\n\x0b\x41geCategory\x12\x0c\n\x08\x43HILDREN\x10\x01\x12\n\n\x06\x41\x44ULTS\x10\x02\x12\x0b\n\x07SENIORS\x10\x04\x12\t\n\x05MIXED\x10\x08\"O\n\x0eGenderCategory\x12\x11\n\rMIXED_GENDERS\x10\x01\x12\x15\n\x11\x43OMPLETELY_FEMALE\x10\x02\x12\x13\n\x0f\x43OMPLETELY_MALE\x10\x04\"5\n\x0cSizeCategory\x12\x0f\n\x0bSMALL_GROUP\x10\x01\x12\t\n\x05GROUP\x10\x02\x12\t\n\x05\x43ROWD\x10\x04\x42\x15\x42\x13GroupHypothesisType')



_GROUPHYPOTHESIS_AGECATEGORY = _descriptor.EnumDescriptor(
  name='AgeCategory',
  full_name='rst.hri.GroupHypothesis.AgeCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHILDREN', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADULTS', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SENIORS', index=2, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MIXED', index=3, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=495,
  serialized_end=558,
)

_GROUPHYPOTHESIS_GENDERCATEGORY = _descriptor.EnumDescriptor(
  name='GenderCategory',
  full_name='rst.hri.GroupHypothesis.GenderCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MIXED_GENDERS', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETELY_FEMALE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETELY_MALE', index=2, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=560,
  serialized_end=639,
)

_GROUPHYPOTHESIS_SIZECATEGORY = _descriptor.EnumDescriptor(
  name='SizeCategory',
  full_name='rst.hri.GroupHypothesis.SizeCategory',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SMALL_GROUP', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GROUP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CROWD', index=2, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=641,
  serialized_end=694,
)


_GROUPHYPOTHESIS = _descriptor.Descriptor(
  name='GroupHypothesis',
  full_name='rst.hri.GroupHypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracking_info', full_name='rst.hri.GroupHypothesis.tracking_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_size_estimate', full_name='rst.hri.GroupHypothesis.group_size_estimate', index=1,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_size_category', full_name='rst.hri.GroupHypothesis.group_size_category', index=2,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='interest_level', full_name='rst.hri.GroupHypothesis.interest_level', index=3,
      number=20, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group_stability', full_name='rst.hri.GroupHypothesis.group_stability', index=4,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age_category', full_name='rst.hri.GroupHypothesis.age_category', index=5,
      number=30, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gender_category', full_name='rst.hri.GroupHypothesis.gender_category', index=6,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stability_cues', full_name='rst.hri.GroupHypothesis.stability_cues', index=7,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GROUPHYPOTHESIS_AGECATEGORY,
    _GROUPHYPOTHESIS_GENDERCATEGORY,
    _GROUPHYPOTHESIS_SIZECATEGORY,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=105,
  serialized_end=694,
)

_GROUPHYPOTHESIS.fields_by_name['tracking_info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_GROUPHYPOTHESIS.fields_by_name['group_size_category'].enum_type = _GROUPHYPOTHESIS_SIZECATEGORY
_GROUPHYPOTHESIS.fields_by_name['age_category'].enum_type = _GROUPHYPOTHESIS_AGECATEGORY
_GROUPHYPOTHESIS.fields_by_name['gender_category'].enum_type = _GROUPHYPOTHESIS_GENDERCATEGORY
_GROUPHYPOTHESIS.fields_by_name['stability_cues'].message_type = rst.math.MatrixDouble_pb2._MATRIXDOUBLE
_GROUPHYPOTHESIS_AGECATEGORY.containing_type = _GROUPHYPOTHESIS;
_GROUPHYPOTHESIS_GENDERCATEGORY.containing_type = _GROUPHYPOTHESIS;
_GROUPHYPOTHESIS_SIZECATEGORY.containing_type = _GROUPHYPOTHESIS;
DESCRIPTOR.message_types_by_name['GroupHypothesis'] = _GROUPHYPOTHESIS

class GroupHypothesis(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _GROUPHYPOTHESIS

  # @@protoc_insertion_point(class_scope:rst.hri.GroupHypothesis)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023GroupHypothesisType')
# @@protoc_insertion_point(module_scope)
