# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/euroc/ColoredPoseSet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/euroc/ColoredPoseSet.proto',
  package='rst.euroc',
  serialized_pb='\n\x1erst/euroc/ColoredPoseSet.proto\x12\trst.euroc\x1a\x17rst/geometry/Pose.proto\"\xec\x01\n\x0e\x43oloredPoseSet\x12\x34\n\x05poses\x18\x01 \x03(\x0b\x32%.rst.euroc.ColoredPoseSet.ColoredPose\x1a\xa3\x01\n\x0b\x43oloredPose\x12 \n\x04pose\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12:\n\x05\x63olor\x18\x02 \x02(\x0b\x32+.rst.euroc.ColoredPoseSet.ColoredPose.Color\x12\x0c\n\x04type\x18\x03 \x01(\t\x1a(\n\x05\x43olor\x12\t\n\x01r\x18\x01 \x02(\x01\x12\t\n\x01g\x18\x02 \x02(\x01\x12\t\n\x01\x62\x18\x03 \x02(\x01\x42\x14\x42\x12\x43oloredPoseSetType')




_COLOREDPOSESET_COLOREDPOSE_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color.r', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g', full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color.g', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='rst.euroc.ColoredPoseSet.ColoredPose.Color.b', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=267,
  serialized_end=307,
)

_COLOREDPOSESET_COLOREDPOSE = _descriptor.Descriptor(
  name='ColoredPose',
  full_name='rst.euroc.ColoredPoseSet.ColoredPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.euroc.ColoredPoseSet.ColoredPose.pose', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='color', full_name='rst.euroc.ColoredPoseSet.ColoredPose.color', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='rst.euroc.ColoredPoseSet.ColoredPose.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_COLOREDPOSESET_COLOREDPOSE_COLOR, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=144,
  serialized_end=307,
)

_COLOREDPOSESET = _descriptor.Descriptor(
  name='ColoredPoseSet',
  full_name='rst.euroc.ColoredPoseSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='poses', full_name='rst.euroc.ColoredPoseSet.poses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_COLOREDPOSESET_COLOREDPOSE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=71,
  serialized_end=307,
)

_COLOREDPOSESET_COLOREDPOSE_COLOR.containing_type = _COLOREDPOSESET_COLOREDPOSE;
_COLOREDPOSESET_COLOREDPOSE.fields_by_name['pose'].message_type = rst.geometry.Pose_pb2._POSE
_COLOREDPOSESET_COLOREDPOSE.fields_by_name['color'].message_type = _COLOREDPOSESET_COLOREDPOSE_COLOR
_COLOREDPOSESET_COLOREDPOSE.containing_type = _COLOREDPOSESET;
_COLOREDPOSESET.fields_by_name['poses'].message_type = _COLOREDPOSESET_COLOREDPOSE
DESCRIPTOR.message_types_by_name['ColoredPoseSet'] = _COLOREDPOSESET

class ColoredPoseSet(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class ColoredPose(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType

    class Color(_message.Message):
      __metaclass__ = _reflection.GeneratedProtocolMessageType
      DESCRIPTOR = _COLOREDPOSESET_COLOREDPOSE_COLOR

      # @@protoc_insertion_point(class_scope:rst.euroc.ColoredPoseSet.ColoredPose.Color)
    DESCRIPTOR = _COLOREDPOSESET_COLOREDPOSE

    # @@protoc_insertion_point(class_scope:rst.euroc.ColoredPoseSet.ColoredPose)
  DESCRIPTOR = _COLOREDPOSESET

  # @@protoc_insertion_point(class_scope:rst.euroc.ColoredPoseSet)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022ColoredPoseSetType')
# @@protoc_insertion_point(module_scope)
