# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/ProprioceptionState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.JointState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/ProprioceptionState.proto',
  package='rst.kinematics',
  serialized_pb='\n(rst/kinematics/ProprioceptionState.proto\x12\x0erst.kinematics\x1a\x1frst/kinematics/JointState.proto\"A\n\x13ProprioceptionState\x12*\n\x06joints\x18\x01 \x03(\x0b\x32\x1a.rst.kinematics.JointStateB\x19\x42\x17ProprioceptionStateType')




_PROPRIOCEPTIONSTATE = _descriptor.Descriptor(
  name='ProprioceptionState',
  full_name='rst.kinematics.ProprioceptionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='joints', full_name='rst.kinematics.ProprioceptionState.joints', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=93,
  serialized_end=158,
)

_PROPRIOCEPTIONSTATE.fields_by_name['joints'].message_type = rst.kinematics.JointState_pb2._JOINTSTATE
DESCRIPTOR.message_types_by_name['ProprioceptionState'] = _PROPRIOCEPTIONSTATE

class ProprioceptionState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PROPRIOCEPTIONSTATE

  # @@protoc_insertion_point(class_scope:rst.kinematics.ProprioceptionState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027ProprioceptionStateType')
# @@protoc_insertion_point(module_scope)
