# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/CameraMatrix3x4.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/CameraMatrix3x4.proto',
  package='rst.vision',
  serialized_pb='\n rst/vision/CameraMatrix3x4.proto\x12\nrst.vision\"\xad\x01\n\x0f\x43\x61meraMatrix3x4\x12\x0b\n\x03\x63\x31\x31\x18\x01 \x02(\x02\x12\x0b\n\x03\x63\x31\x32\x18\x02 \x02(\x02\x12\x0b\n\x03\x63\x31\x33\x18\x03 \x02(\x02\x12\x0b\n\x03\x63\x31\x34\x18\x04 \x02(\x02\x12\x0b\n\x03\x63\x32\x31\x18\x05 \x02(\x02\x12\x0b\n\x03\x63\x32\x32\x18\x06 \x02(\x02\x12\x0b\n\x03\x63\x32\x33\x18\x07 \x02(\x02\x12\x0b\n\x03\x63\x32\x34\x18\x08 \x02(\x02\x12\x0b\n\x03\x63\x33\x31\x18\t \x02(\x02\x12\x0b\n\x03\x63\x33\x32\x18\n \x02(\x02\x12\x0b\n\x03\x63\x33\x33\x18\x0b \x02(\x02\x12\x0b\n\x03\x63\x33\x34\x18\x0c \x02(\x02\x42\x15\x42\x13\x43\x61meraMatrix3x4Type')




_CAMERAMATRIX3X4 = _descriptor.Descriptor(
  name='CameraMatrix3x4',
  full_name='rst.vision.CameraMatrix3x4',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='c11', full_name='rst.vision.CameraMatrix3x4.c11', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c12', full_name='rst.vision.CameraMatrix3x4.c12', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c13', full_name='rst.vision.CameraMatrix3x4.c13', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c14', full_name='rst.vision.CameraMatrix3x4.c14', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c21', full_name='rst.vision.CameraMatrix3x4.c21', index=4,
      number=5, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c22', full_name='rst.vision.CameraMatrix3x4.c22', index=5,
      number=6, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c23', full_name='rst.vision.CameraMatrix3x4.c23', index=6,
      number=7, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c24', full_name='rst.vision.CameraMatrix3x4.c24', index=7,
      number=8, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c31', full_name='rst.vision.CameraMatrix3x4.c31', index=8,
      number=9, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c32', full_name='rst.vision.CameraMatrix3x4.c32', index=9,
      number=10, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c33', full_name='rst.vision.CameraMatrix3x4.c33', index=10,
      number=11, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c34', full_name='rst.vision.CameraMatrix3x4.c34', index=11,
      number=12, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=49,
  serialized_end=222,
)

DESCRIPTOR.message_types_by_name['CameraMatrix3x4'] = _CAMERAMATRIX3X4

class CameraMatrix3x4(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CAMERAMATRIX3X4

  # @@protoc_insertion_point(class_scope:rst.vision.CameraMatrix3x4)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023CameraMatrix3x4Type')
# @@protoc_insertion_point(module_scope)
