# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/CalibrationMatrices.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.vision.CameraMatrix3x4_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/CalibrationMatrices.proto',
  package='rst.vision',
  serialized_pb='\n$rst/vision/CalibrationMatrices.proto\x12\nrst.vision\x1a rst/vision/CameraMatrix3x4.proto\"l\n\x13\x43\x61librationMatrices\x12)\n\x04left\x18\x01 \x02(\x0b\x32\x1b.rst.vision.CameraMatrix3x4\x12*\n\x05right\x18\x02 \x02(\x0b\x32\x1b.rst.vision.CameraMatrix3x4B\x19\x42\x17\x43\x61librationMatricesType')




_CALIBRATIONMATRICES = _descriptor.Descriptor(
  name='CalibrationMatrices',
  full_name='rst.vision.CalibrationMatrices',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='left', full_name='rst.vision.CalibrationMatrices.left', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='right', full_name='rst.vision.CalibrationMatrices.right', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=86,
  serialized_end=194,
)

_CALIBRATIONMATRICES.fields_by_name['left'].message_type = rst.vision.CameraMatrix3x4_pb2._CAMERAMATRIX3X4
_CALIBRATIONMATRICES.fields_by_name['right'].message_type = rst.vision.CameraMatrix3x4_pb2._CAMERAMATRIX3X4
DESCRIPTOR.message_types_by_name['CalibrationMatrices'] = _CALIBRATIONMATRICES

class CalibrationMatrices(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CALIBRATIONMATRICES

  # @@protoc_insertion_point(class_scope:rst.vision.CalibrationMatrices)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\027CalibrationMatricesType')
# @@protoc_insertion_point(module_scope)
